@@ -62,6 +62,12 @@ class MemorySummaryField(base.CompositeField):
     """
 
 
+class StatusField(base.CompositeField):
+    state = base.Field('State')
+    health = base.Field('Health')
+    health_rollup = base.Field('HealthRollup')
+
+
 class System(base.ResourceBase):
 
     asset_tag = base.Field('AssetTag')
@@ -105,6 +111,9 @@ class System(base.ResourceBase):
     sku = base.Field('SKU')
     """The system stock-keeping unit"""
 
+    status = StatusField('Status')
+    """The system status"""
+
     # TODO(lucasagomes): Create mappings for the system_type
     system_type = base.Field('SystemType')
     """The system type"""
@@ -214,7 +223,7 @@ class System(base.ResourceBase):
         if enabled not in sys_maps.BOOT_SOURCE_ENABLED_MAP_REV:
             raise exceptions.InvalidParameterValueError(
                 parameter='enabled', value=enabled,
-                valid_values=list(sys_maps.BOOT_SOURCE_TARGET_MAP_REV))
+                valid_values=list(sys_maps.BOOT_SOURCE_ENABLED_MAP_REV))
 
         data = {
             'Boot': {
@@ -248,25 +257,28 @@ class System(base.ResourceBase):
 
     @property
     def processors(self):
-        """Property to provide reference to `ProcessorCollection` instance
+        """Property to reference `ProcessorCollection` instance
 
-        It is calculated once when the first time it is queried. On refresh,
-        this property gets reset.
+        It is set once when the first time it is queried. On refresh,
+        this property is marked as stale (greedy-refresh not done).
+        Here the actual refresh of the sub-resource happens, if stale.
         """
         if self._processors is None:
             self._processors = processor.ProcessorCollection(
                 self._conn, self._get_processor_collection_path(),
                 redfish_version=self.redfish_version)
 
+        self._processors.refresh(force=False)
         return self._processors
 
-    def refresh(self):
-        super(System, self).refresh()
-        self._processors = None
-        self._ethernet_interfaces = None
-
     @property
     def ethernet_interfaces(self):
+        """Property to reference `EthernetInterfaceCollection` instance
+
+        It is set once when the first time it is queried. On refresh,
+        this property is marked as stale (greedy-refresh not done).
+        Here the actual refresh of the sub-resource happens, if stale.
+        """
         if self._ethernet_interfaces is None:
             self._ethernet_interfaces = (
                 ethernet_interface.EthernetInterfaceCollection(
@@ -274,8 +286,21 @@ class System(base.ResourceBase):
                     utils.get_sub_resource_path_by(self, "EthernetInterfaces"),
                     redfish_version=self.redfish_version))
 
+        self._ethernet_interfaces.refresh(force=False)
         return self._ethernet_interfaces
 
+    def _do_refresh(self, force=False):
+        """Do custom resource specific refresh activities
+
+        On refresh, all sub-resources are marked as stale, i.e.
+        greedy-refresh not done for them unless forced by ``force``
+        argument.
+        """
+        if self._processors is not None:
+            self._processors.invalidate(force)
+        if self._ethernet_interfaces is not None:
+            self._ethernet_interfaces.invalidate(force)
+
 
 class SystemCollection(base.ResourceCollectionBase):
 
