@@ -21,6 +21,7 @@ import sushy
 from sushy import exceptions
 from sushy.resources.system import constants as sys_cons
 from sushy.resources.system import ethernet_interface
+from sushy.resources.system import mappings as sys_map
 from sushy.resources.system import processor
 from sushy.resources.system import system
 from sushy.tests.unit import base
@@ -55,6 +56,9 @@ class SystemTestCase(base.TestCase):
         self.assertEqual('Physical', self.sys_inst.system_type)
         self.assertEqual('38947555-7742-3448-3784-823347823834',
                          self.sys_inst.uuid)
+        self.assertEqual('Enabled', self.sys_inst.status.state)
+        self.assertEqual('OK', self.sys_inst.status.health)
+        self.assertEqual('OK', self.sys_inst.status.health_rollup)
         self.assertEqual(sushy.SYSTEM_POWER_STATE_ON,
                          self.sys_inst.power_state)
         self.assertEqual(96, self.sys_inst.memory_summary.size_gib)
@@ -212,10 +216,14 @@ class SystemTestCase(base.TestCase):
                           'invalid-target')
 
     def test_set_system_boot_source_invalid_enabled(self):
-        self.assertRaises(exceptions.InvalidParameterValueError,
-                          self.sys_inst.set_system_boot_source,
-                          sushy.BOOT_SOURCE_TARGET_HDD,
-                          enabled='invalid-enabled')
+        with self.assertRaisesRegex(
+            exceptions.InvalidParameterValueError,
+            '"enabled" value.*{0}'.format(
+                list(sys_map.BOOT_SOURCE_ENABLED_MAP_REV))):
+
+            self.sys_inst.set_system_boot_source(
+                sushy.BOOT_SOURCE_TARGET_HDD,
+                enabled='invalid-enabled')
 
     def test__get_processor_collection_path_missing_processors_attr(self):
         self.sys_inst._json.pop('Processors')
@@ -290,10 +298,13 @@ class SystemTestCase(base.TestCase):
         # On refreshing the system instance...
         with open('sushy/tests/unit/json_samples/system.json', 'r') as f:
             self.conn.get.return_value.json.return_value = json.loads(f.read())
-        self.sys_inst.refresh()
+
+        self.sys_inst.invalidate()
+        self.sys_inst.refresh(force=False)
 
         # | WHEN & THEN |
-        self.assertIsNone(self.sys_inst._processors)
+        self.assertIsNotNone(self.sys_inst._processors)
+        self.assertTrue(self.sys_inst._processors._is_stale)
 
         # | GIVEN |
         with open('sushy/tests/unit/json_samples/processor_collection.json',
@@ -302,6 +313,7 @@ class SystemTestCase(base.TestCase):
         # | WHEN & THEN |
         self.assertIsInstance(self.sys_inst.processors,
                               processor.ProcessorCollection)
+        self.assertFalse(self.sys_inst._processors._is_stale)
 
     def _setUp_processor_summary(self):
         self.conn.get.return_value.json.reset_mock()
@@ -358,8 +370,11 @@ class SystemTestCase(base.TestCase):
 
         self.assertIsNone(self.sys_inst._ethernet_interfaces)
         actual_macs = self.sys_inst.ethernet_interfaces.summary
-        self.assertEqual({'12:44:6A:3B:04:11': sys_cons.HEALTH_STATE_ENABLED},
-                         actual_macs)
+        expected_macs = (
+            {'12:44:6A:3B:04:11':
+             sys_map.HEALTH_STATE_VALUE_MAP_REV.get(
+                 sys_cons.HEALTH_STATE_ENABLED)})
+        self.assertEqual(expected_macs, actual_macs)
         self.assertIsInstance(self.sys_inst._ethernet_interfaces,
                               ethernet_interface.EthernetInterfaceCollection)
 
